<?php
/*
Plugin Name: WordPress Hook Sniffer
Plugin URI: http://jeffsayre.com/2010/04/29/introducing-wordpress-hook-sniffer-a-developer-plugin/
Description: This is a developer's tool that sniffs out the firing sequence of WordPress action and filter hooks. DO NOT USE in a production environment.
Version: 0.12
Revision Date: May 3, 2010
Requires at least: WP/MU 2.9.2
Tested up to: WP/MU 2.9.2
License: GNU General Public License 3.0 (GPL) http://www.gnu.org/licenses/gpl.html
Author: Jeff Sayre
Author URI: http://jeffsayre.com/
Site Wide Only: true

Copyright 2010 Jeff Sayre

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3.0 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


/**
 * wp_hook_sniff_init()
 *
 * Initialize basic constants and make sure WordPress
 * is installed and activated. If true, then allow for 
 * plugin to finish loading.
 *
 * @since 0.1
 */
function wp_hook_sniff_init() {
		
	/* Define the component's current version */
	define( 'WP_HOOK_PLUGIN_VERSION', 0.12 );
		
	/* Define the component's parent folder name */
	define( 'WP_HOOK_PLUGIN_NAME', 'wordpress-hook-sniffer' );
	
	/* Define component's directory and URL Paths */
	define( 'WP_HOOK_PLUGIN_DIR', WP_PLUGIN_DIR . '/' . WP_HOOK_PLUGIN_NAME );
	define( 'WP_HOOK_PLUGIN_URL', WP_PLUGIN_URL . '/' . WP_HOOK_PLUGIN_NAME );
	
	/* WordPress is installed and activated, finish initialization and go! */
	require_once( WP_HOOK_PLUGIN_DIR . '/wp-hook-sniff-core.php' );
	
	/* WP Hook Sniffer Action Hook
	 *
	 * This hook allows those functions that are dependent on 
	 * the WP Hook Sniffer to hook into it in a safe
	 * manner -- only when it is installed and activated.
	 */
	do_action( 'wp_hook_sniff_init_event' );
}
add_action( 'plugins_loaded', 'wp_hook_sniff_init', 0 );


/**
 * wp_hook_sniff_plugin_activated()
 *
 * Register plugin activation with WordPress and
 * set the activation hook.
 *
 * @since 0.1
 */
function wp_hook_sniff_plugin_activated() {
	do_action( 'wp_hook_sniff_loader_activate' );
}
register_activation_hook( 'wordpress-hook-sniffer/wp-hook-sniffer.php', 'wp_hook_sniff_plugin_activated' );


/**
 * wp_hook_sniff_plugin_deactivated()
 *
 * Register plugin deactivation with WordPress and
 * set the deactivation hook.
 *
 * @since 0.1
 */
function wp_hook_sniff_plugin_deactivated() {
	if ( !function_exists( 'delete_site_option') )
		return false;

	/* If you enable the code below, then you will have to reset
	 * any previously disabled privacy objects. In other words,
	 * when you reactivate, the privacy component will run with
	 * all privacy objects fully active. By keeping this code
	 * disabled, you can easily deactivate privacy filtering and
	 * then reactivate it without lossing any previous settings.
	 */
	//delete_site_option( 'bp-authz-db-version' );
	//delete_site_option( 'bp-privacy-components-deactivated' );
	//delete_site_option( 'bp-privacy-acceptance' );
	
	do_action( 'wp_hook_sniff_loader_deactivate' );
}
register_deactivation_hook( 'wordpress-hook-sniffer/wp-hook-sniffer.php', 'wp_hook_sniff_plugin_deactivated' );

?>